lcvtoolbox.vision.encoding.numpy.encode\_array\_pickle
======================================================

.. currentmodule:: lcvtoolbox.vision.encoding.numpy

.. autofunction:: encode_array_pickle